@@ -3,7 +3,7 @@
 # Author: Edward Kawas <edward.kawas@gmail.com>,
 # For copyright and disclaimer see below.
 #
-# $Id: SADIServiceParser.pm,v 1.4 2010-03-08 19:28:53 ubuntu Exp $
+# $Id: SADIServiceParser.pm,v 1.2 2009-08-27 18:15:33 ubuntu Exp $
 #-----------------------------------------------------------------
 package SADI::OWL::SADIServiceParser;
 use strict;
@@ -16,7 +16,6 @@ use RDF::Core::Resource;
 
 use SADI::Utils;
 use SADI::Service::Instance;
-use SADI::Service::UnitTest;
 
 use SADI::RDF::Predicates::DC_PROTEGE;
 use SADI::RDF::Predicates::OMG_LSID;
@@ -27,9 +26,7 @@ use SADI::RDF::Predicates::RDFS;
 use LS::ID;
 
 use vars qw /$VERSION/;
-$VERSION = sprintf "%d.%02d", q$Revision: 1.4 $ =~ /: (\d+)\.(\d+)/;
-
-=pod
+$VERSION = sprintf "%d.%02d", q$Revision: 1.2 $ =~ /: (\d+)\.(\d+)/;
 
 =head1 NAME
 
@@ -74,6 +71,8 @@ parsed and held in memory.
 
 =cut
 
+#-----------------------------------------------------------------
+
 =head1 SUBROUTINES
 
 =cut
@@ -100,8 +99,6 @@ sub new {
 	return $self;
 }
 
-=pod
-
 =head2 getServices 
 
 Downloads RDF from $url, parses it and returns an arrayref of C<SADI::Service::Instance>.
@@ -373,72 +370,6 @@ sub getServices {
 		# dont need the performsTask node anymore
 		$performs = undef;
 
-		# process any unit test information
-        my $unit_test =
-          $model->getObjects(
-                              $hasOperation,
-                              new RDF::Core::Resource(
-                                        SADI::RDF::Predicates::FETA->hasUnitTest
-                              )
-          );
-        $unit_test = [] unless @$unit_test;
-        foreach my $ut (@$unit_test) {
-            my $unit = new SADI::Service::UnitTest;
-
-            # get example input
-            $val =
-              $model->getObjects(
-                                  $ut,
-                                  new RDF::Core::Resource(
-                                       SADI::RDF::Predicates::FETA->exampleInput
-                                  )
-              );
-            $val = "" unless $$val[0];
-            $val = $$val[0]->getValue if ref($val) eq 'ARRAY' and $$val[0];
-            $unit->input( SADI::Utils::trim($val) );
-
-            # get example output
-            $val =
-              $model->getObjects(
-                                  $ut,
-                                  new RDF::Core::Resource(
-                                                     SADI::RDF::Predicates::FETA
-                                                       ->validOutputXML
-                                  )
-              );
-            $val = "" unless $$val[0];
-            $val = $$val[0]->getValue if ref($val) eq 'ARRAY' and $$val[0];
-            $unit->output( SADI::Utils::trim($val) );
-
-            # get regex
-            $val =
-              $model->getObjects(
-                                  $ut,
-                                  new RDF::Core::Resource(
-                                         SADI::RDF::Predicates::FETA->validREGEX
-                                  )
-              );
-            $val = "" unless $$val[0];
-            $val = $$val[0]->getValue if ref($val) eq 'ARRAY' and $$val[0];
-            $unit->regex( SADI::Utils::trim($val) );
-
-            # get xpath
-            $val =
-              $model->getObjects(
-                                  $ut,
-                                  new RDF::Core::Resource(
-                                         SADI::RDF::Predicates::FETA->validXPath
-                                  )
-              );
-            $val = "" unless $$val[0];
-            $val = $$val[0]->getValue if ref($val) eq 'ARRAY' and $$val[0];
-            $unit->xpath( SADI::Utils::trim($val) );
-
-            # add the unit test in the service
-            push @{ $instance->UnitTest }, $unit;
-        }
-
-
 		# this service is done ...
 		push @services, $instance;
 
@@ -453,5 +384,4 @@ sub getServices {
 }
 
 1;
-
 __END__
